@@ -16,11 +16,7 @@ class RdpPreferences : public KCModule
     Q_OBJECT
 
 public:
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    explicit RdpPreferences(QWidget *parent, const QVariantList &args);
-#else
     explicit RdpPreferences(QObject *parent);
-#endif
     ~RdpPreferences() override;
 
     void save() override;
